@@ -68,6 +68,7 @@ app = FastAPI(
     openapi_url="/api",
     docs_url="/api.html",
     lifespan=lifespan,
+    root_path=settings.root_path,
 )
 
 # custom template directory
@@ -79,10 +80,8 @@ templates_location: List[Any] = (
 # default template directory
 templates_location.append(jinja2.PackageLoader(__package__, "templates"))
 
-templates = Jinja2Templates(
-    directory="",  # we need to set a dummy directory variable, see https://github.com/encode/starlette/issues/1214
-    loader=jinja2.ChoiceLoader(templates_location),
-)  # type: ignore
+jinja2_env = jinja2.Environment(loader=jinja2.ChoiceLoader(templates_location))
+templates = Jinja2Templates(env=jinja2_env)
 
 ogc_api = Endpoints(
     title=settings.name,
@@ -117,6 +116,8 @@ if settings.catalog_ttl:
         exclude_functions=db_settings.exclude_functions,
         exclude_function_schemas=db_settings.exclude_function_schemas,
         spatial=db_settings.only_spatial_tables,
+        spatial_extent=db_settings.spatial_extent,
+        datetime_extent=db_settings.datetime_extent,
     )
 
 add_exception_handlers(app, DEFAULT_STATUS_CODES)
@@ -154,5 +155,7 @@ if settings.debug:
             exclude_functions=db_settings.exclude_functions,
             exclude_function_schemas=db_settings.exclude_function_schemas,
             spatial=db_settings.only_spatial_tables,
+            spatial_extent=db_settings.spatial_extent,
+            datetime_extent=db_settings.datetime_extent,
         )
         return request.app.state.collection_catalog
